:mod:`oujago.nlp.postag`
=========================

.. automodule:: oujago.nlp.postag

.. autosummary::

    BasePOS
    LTPPOS
    JiebaPOS
    MoranPOS
    pos
    get_pos_mode
    get_pos_mode


Detailed Description
--------------------


.. autoclass:: BasePOS
    :members:


.. autoclass:: LTPPOS
    :members:

.. autoclass:: JiebaPOS
    :members:

.. autoclass:: MoranPOS
    :members:

.. autofunction:: pos
.. autofunction:: set_pos_mode
.. autofunction:: get_pos_mode
